@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.092;
+our $VERSION = 1.093;
 
 use Prty::Html::Table::List;
 use Prty::Unindent;
@@ -16,7 +16,7 @@ use Prty::Hash;
 
 =head1 NAME
 
-Prty::JQuery::DataTable - Erzeuge eine jQuery DataTables-Tabelle
+Prty::JQuery::DataTable - Erzeuge eine HTML/JavaScript DataTables-Tabelle
 
 =head1 BASE CLASS
 
@@ -24,10 +24,9 @@ L<Prty::Hash>
 
 =head1 DESCRIPTION
 
-Hompage DataTables-Plugin: L<https://datatables.net/>
-
-Die Klasse erzeugt den HTML- und JavaScript-Code für
-DataTable-Widgets.
+Die Klasse liefert den HTML- und JavaScript-Code für ein
+DataTable-Widget. Hompage des DataTables-Plugin:
+L<https://datatables.net/>
 
 =head1 ATTRIBUTES
 
@@ -39,20 +38,19 @@ CSS-Klasse der DataTable (des Table-Elements).
 
 =item columns => \@columns (Default: [])
 
-Spezifikation der Kolumnen. Jeder Eintrag ist ein Hash mit den
-Komponenten:
+Referenz auf eine Liste mit Kolumnen-Spezifikationen. Eine einzelne
+Kolumnen-Spezifikation ist ein Hash mit den Komponenten:
 
     {
-        name=>$name,
-        title=>$title,
-        align=>'left'|'center'|'right',
-        orderable=>$bool,
-        searchable=>$bool,
-        visible=>$bool,
+        name=>$name,        # interner Name, insbes. f. Wert-Lookup
+        title=>$title,      # Kolumnenüberschrift
+        align=>$align,      # 'left'|'center'|'right' (Default: 'left')
+        orderable=>$bool,   # 0|1 (Default: 1)
+        searchable=>$bool,  # 0|1 (Default: 1)
+        visible=>$bool,     # 0|1 (Default: 1)
     }
 
-Nicht benötigte Komponenten können weggelassen werden, es gilt
-dann der Defaultwert.
+Nicht benötigte Komponenten können weggelassen werden.
 
 =item id => $id (Default: undef)
 
@@ -73,8 +71,8 @@ generiert und zu diesem Code hinzugefügt.
 =item rowCallback => $sub (Default: s.u.)
 
 Referenz auf eine Subroutine, die für jedes Row-Objekt die
-darzustellende Zeileninformation (für tr- und td-Tag) liefert.
-Default:
+darzustellende Zeileninformation (für tr- und td-Tag) liefert
+(siehe Prty::Html::Table::List). Default:
 
     rowCallback => sub {
         my ($row,$i,$columnA) = @_;
@@ -97,7 +95,17 @@ Liste der Row-Objekte. Für jedes Element wird die Callback-Methode
 
 =head1 EXAMPLE
 
-Das Programm
+Darstellung im Browser:
+
+=begin html
+
+<p class="sdoc-fig-p">
+  <img class="sdoc-fig-img" src="https://raw.github.com/s31tz/Prty/master/img/prty_jquery_datatable_example01.png" width="499" height="149" alt="" />
+</p>
+
+=end html
+
+Programm:
 
     my $tab = Prty::Database::Row::Object->makeTable(
         [qw/per_id per_vorname per_nachname per_geburtsdatum/],
@@ -161,7 +169,7 @@ Das Programm
         ],
     );
 
-erzeugt (lange Zeilen umbrochen)
+Generierte HTML-Seite:
 
     <!DOCTYPE html>
     
@@ -538,7 +546,7 @@ sub getColumns {
 
 =head1 VERSION
 
-1.092
+1.093
 
 =head1 AUTHOR
 
